OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Stiki",
    "All contacts" : "Vsi stiki",
    "Details" : "Podrobnosti",
    "Copy to full name" : "Kopiraj v polno ime",
    "Add new property" : "Dodaj novo lastnost",
    "Choose property type" : "Izbor vrste lastnosti",
    "Add a new picture" : "Dodaj novo sliko",
    "Upload a new picture" : "Pošlji novo sliko",
    "Choose from files" : "Izbor iz datotek",
    "Delete picture" : "Izbriši sliko",
    "Download picture" : "Prejmi sliko",
    "Pick an avatar" : "Izbor podobe",
    "Error while processing the picture." : "Prišlo je do napake med obdelavo slike.",
    "No contact selected" : "Ni izbranega stika",
    "Loading" : "Poteka nalaganje",
    "Name" : "Ime",
    "Company" : "Ustanova",
    "Title" : "Naziv",
    "Download" : "Prejmi",
    "Generate QR Code" : "Ustvari kodo QR",
    "Delete" : "Izbriši",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Stik, ki ga skušate urediti je spremenjen. Stike je treba ročno osvežiti, vsa nadaljnja urejanja pa bodo izbrisana.",
    "Addressbook" : "Imenik",
    "Groups" : "Skupine",
    "New contact" : "Nov stik",
    "Syntax error. Cannot open the contact." : "Napaka skladnje. Ni mogoče odpreti podatkov stika.",
    "No errors" : "Ni zaznanih napak",
    "Open your browser console for more details" : "Več podrobnosti je izpisanih v konzoli brskalnika",
    "Select type" : "Izbor vrste",
    "Select Date" : "Izbor datuma",
    "Add contact in group" : "Dodaj stik v skupino",
    "No results" : "Ni zadetkov",
    "Last modified" : "Nazadnje spremenjeno",
    "Select option" : "Izbor možnosti",
    "Rename" : "Preimenuj",
    "Enabled" : "Omogočeno",
    "Disabled" : "Onemogočeno",
    "Copied" : "Kopirano!",
    "Can not copy" : "Ni mogoče kopirati!",
    "Copy link" : "Kopiraj povezavo",
    "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
    "No users or groups" : "Ni uporabnikov oziroma skupin",
    "can edit" : "lahko ureja",
    "Unable to delete the share." : "Ni mogoče izbrisati souporabe.",
    "Unable to change permissions." : "Ni mogoče spremeniti dovoljenj.",
    "Importing into" : "Uvažanje informacij",
    "Import into" : "Uvozi v",
    "Address book name" : "Ime imenika",
    "First name" : "Ime",
    "Last name" : "Priimek",
    "Display name" : "Prikazano ime",
    "Sort by {sorting}" : "Razvrsti po {sorting}",
    "Not grouped" : "Brez skupine",
    "Nickname" : "Vzdevek",
    "Detailed name" : "Podrobno ime",
    "Additional names" : "Druga imena",
    "Prefix" : "Predpona",
    "Suffix" : "Pripona",
    "Notes" : "Opombe",
    "Website" : "Spletna stran",
    "Location" : "Mesto",
    "Federated Cloud ID" : "ID zveznega oblaka",
    "Home" : "Domači naslov",
    "Work" : "Službeni naslov",
    "Other" : "Drugo",
    "Address" : "Naslov",
    "Post office box" : "Poštni predal",
    "Extended address" : "Razširjen naslov",
    "City" : "Mesto",
    "State or province" : "Zvezna država ali provinca",
    "Postal code" : "Poštna številka",
    "Country" : "Država",
    "Birthday" : "Rojstni dan",
    "Anniversary" : "Obletnica",
    "Date of death" : "Datum smrti",
    "Email" : "Elektronski naslov",
    "Instant messaging" : "Hipno sporočanje",
    "Phone" : "Telefon",
    "Mobile" : "Mobilni telefon",
    "Work mobile" : "Službeni mobilni telefon",
    "Home mobile" : "Osebni mobilni telefon",
    "Fax" : "Faks",
    "Fax home" : "Domači faks",
    "Fax work" : "Službeni faks",
    "Pager" : "Pozivnik",
    "Voice" : "Glasovna pošta",
    "Car" : "Avto",
    "Work pager" : "Službeni pozivnik",
    "Social network" : "Družbeno omrežje",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "Naslov URL profila, na primer https://www.facebook.com/Nextclouders/ ",
    "Relationship" : "Razmerje",
    "Spouse" : "Partner",
    "Child" : "Otrok",
    "Mother" : "Mati",
    "Father" : "Oče",
    "Parent" : "Starš",
    "Brother" : "Brat",
    "Sister" : "Sestra",
    "Relative" : "Sorodnik",
    "Friend" : "Prijatelj",
    "Colleague" : "Znanec",
    "Manager" : "Vodja",
    "Assistant" : "Pomočnik",
    "Contact" : "Stik",
    "Co-worker" : "Sodelavec",
    "Gender" : "Spol",
    "Female" : "Ženski",
    "Male" : "Moški",
    "None" : "Brez",
    "Unknown" : "Neznano",
    "Timezone" : "Časovni pas",
    "An error occurred" : "Prišlo je do napake."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
